@@ -2,12 +2,13 @@ package Dist::Zilla::Plugin::AlienBuild;
 
 use strict;
 use warnings;
+use 5.014;
 use Moose;
 use List::Util qw( first );
 use Path::Tiny qw( path );
 
 # ABSTRACT: Use Alien::Build with Dist::Zilla
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 
 with 'Dist::Zilla::Role::FileMunger';
@@ -25,10 +26,12 @@ sub register_prereqs
     $alienfile->spew($file->content);
     my $build = Alien::Build->load($alienfile);
 
+    my $ab_version = '0.02';
+
     # Configure requires...
     $self->zilla->register_prereqs(
       { phase => 'configure' },
-      'Alien::Build::MM' => '0.01',
+      'Alien::Build::MM' => $ab_version,
       'ExtUtils::MakeMaker' => '6.52',
       %{ $build->requires('configure') },
     );
@@ -36,7 +39,7 @@ sub register_prereqs
     # Build requires...
     $self->zilla->register_prereqs(
       { phase => 'build' },
-      'Alien::Build::MM' => '0.01',
+      'Alien::Build::MM' => $ab_version,
       %{ $build->requires('any') },
     );
   }
@@ -111,7 +114,7 @@ Dist::Zilla::Plugin::AlienBuild - Use Alien::Build with Dist::Zilla
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
